<?php
/**
 * An example file demonstrating how to add all controls.
 *
 * @package     Kirki
 * @category    Core
 * @author      Aristeides Stathopoulos
 * @copyright   Copyright (c) 2017, Aristeides Stathopoulos
 * @license     http://opensource.org/licenses/https://opensource.org/licenses/MIT
 * @since       3.0.12
 */
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// Do not proceed if Kirki does not exist.
if ( ! class_exists( 'Kirki' ) ) {
	return;
}
/**
 * First of all, add the config.
 *
 * @link https://aristath.github.io/kirki/docs/getting-started/config.html
 */
Kirki::add_config(
	'kirki_demo', array(
		'capability'  => 'edit_theme_options',
		'option_type' => 'theme_mod',
	)
);
/**
 * Add a panel.
 *
 * @link https://aristath.github.io/kirki/docs/getting-started/panels.html
 */
Kirki::add_panel(
	'aigen_options_panel', array(
		'priority'    => 10,
		'title'       => esc_attr__( 'aigen Options Panel', 'aigen' ),
		'description' => esc_attr__( 'Config Your Theme Options Here.', 'aigen' ),
	)
);
/**
 * Add Sections.
 *
 * We'll be doing things a bit differently here, just to demonstrate an example.
 * We're going to define 1 section per control-type just to keep things clean and separate.
 *
 * @link https://aristath.github.io/kirki/docs/getting-started/sections.html
 */
$sections = array(
	'body'      => array( esc_attr__( 'Main Body Style', 'aigen' ), '' ),
	'colors'	=> array( esc_attr__('Theme Colors', 'aigen'), ''),
	'fonts'	=> array( esc_attr__('Theme Fonts', 'aigen'), ''),
	'page_banner'      => array( esc_attr__( 'Page Banner Style', 'aigen' ), '' ),
	'social'	=> array( esc_attr__('Social Network Links', 'aigen'), ''),
	'footer'	=> array( esc_attr__('Footer Options', 'aigen'), ''),
	'header'	=> array( esc_attr__('Header Options', 'aigen'), ''),
);
foreach ( $sections as $section_id => $section ) {
	$section_args = array(
		'title'       => $section[0],
		'description' => $section[1],
		'panel'       => 'aigen_options_panel',
	);
	if ( isset( $section[2] ) ) {
		$section_args['type'] = $section[2];
	}
	Kirki::add_section( str_replace( '-', '_', $section_id ) . '_section', $section_args );
}
/**
 * A proxy function. Automatically passes-on the config-id.
 *
 * @param array $args The field arguments.
 */
function my_config_kirki_add_field( $args ) {
	Kirki::add_field( 'kirki_demo', $args );
}


// logo max-width
my_config_kirki_add_field(
	array(
		'type'        => 'dimensions',
		'settings'    => 'logo_dimensions',
		'label'       => esc_attr__( 'Logo Dimension Control', 'aigen' ),
		'section'     => 'body_section',
		'default'     => [
			'max-width'  => '180px',
		],
		'choices'     => [
			'labels' => [
				
				'max-width'  => esc_html__( 'Max Width', 'aigen' ),
			],
		],
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'dimension',
		'settings'    => 'image_radius',
		'label'       => esc_attr__( 'Images Radius', 'aigen' ),
		'description' => esc_attr__( 'Theme Images Border Radius.', 'aigen' ),
		'section'     => 'body_section',
		'default'     => '5px',
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'dimension',
		'settings'    => 'box_radius',
		'label'       => esc_attr__( 'Theme Radius', 'aigen' ),
		'description' => esc_attr__( 'Theme boxes, posts, etc, Border Radius.', 'aigen' ),
		'section'     => 'body_section',
		'default'     => '5px',
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'color',
		'settings'    => 'main_color',
		'label'       => esc_attr__( 'Primary Color 1', 'aigen' ),
		'description' => esc_attr__( 'your Main Color Style 1.', 'aigen' ),
		'section'     => 'colors_section',
		'default'     => '#6228b1',
		
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'color',
		'settings'    => 'main_color2',
		'label'       => esc_attr__( 'Primary Color 2', 'aigen' ),
		'description' => esc_attr__( 'your Main Color Style 2.', 'aigen' ),
		'section'     => 'colors_section',
		'default'     => '#eb4034',
		
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'color',
		'settings'    => 'heading_color',
		'label'       => esc_attr__( 'Heading Color', 'aigen' ),
		'description' => esc_attr__( 'Sections & Posts Title color', 'aigen' ),
		'section'     => 'colors_section',
		'default'     => '#55558b',
		
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'color',
		'settings'    => 'text_color',
		'label'       => esc_attr__( 'Text Color', 'aigen' ),
		'description' => esc_attr__( 'paragraphs text color', 'aigen' ),
		'section'     => 'colors_section',
		'default'     => '#55558b',
		
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'color',
		'settings'    => 'sky_color',
		'label'       => esc_attr__( 'Sky Light Color', 'aigen' ),
		'description' => esc_attr__( 'Sections sky light color', 'aigen' ),
		'section'     => 'colors_section',
		'default'     => '#edf8ff',
		
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'color',
		'settings'    => 'trans_color',
		'label'       => esc_attr__( 'RGB Color with opacity', 'aigen' ),
		'description' => esc_attr__( 'overlay posts with background color opacity', 'aigen' ),
		'section'     => 'colors_section',
		'default'     => 'rgba(98, 40, 177, 0.8)',
		
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'typography',
		'settings'    => 'title_typo',
		'label'       => esc_attr__( 'Titles Font Family', 'aigen' ),
		'section'     => 'fonts_section',
		'default'     => array(
			'font-family'    => 'Rubik',
		),
		'priority'    => 10,
		'output'      => array(
			array(
				'element' => 'h1, h2, h3, h4, h5, h6',
			),
		),
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'typography',
		'settings'    => 'text_typo',
		'label'       => esc_attr__( 'Text Font Family', 'aigen' ),
		'section'     => 'fonts_section',
		'default'     => array(
			'font-family'    => 'Play',
		),
		'priority'    => 10,
		'output'      => array(
			array(
				'element' => 'body, p, .paragraph',
			),
		),
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'typography',
		'settings'    => 'menu_typo',
		'label'       => esc_attr__( 'Menu Font Family', 'aigen' ),
		'section'     => 'fonts_section',
		'default'     => array(
			'font-family'    => 'Quando',
		),
		'priority'    => 10,
		'output'      => array(
			array(
				'element' => '
						.navbar .navbar-nav > li > a,
						.standard-post2 h4,
						.card-post.card-padding h4,
						.single-post-box .post-content blockquote,
						.single-post-box .post-content blockquote p,
						.single-post-box .post-content blockquote:after,
						.about-section2 .highlight-box p,
						footer .widget-area-part ul.tag-list li a,
						footer .widget-area-part div.tagcloud a,
						footer .widget-area-part ul.popular-list li h4
					',
			),
		),
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'switch',
		'settings'    => 'switch_header_socials',
		'label'       => esc_html__( 'Enable/Disable Social Icons', 'aigen' ),
		'section'     => 'header_section',
		'default'     => 'on',
		'priority'    => 10,
		'choices'     => [
			'on'  => esc_html__( 'Enable', 'aigen' ),
			'off' => esc_html__( 'Disable', 'aigen' ),
		],
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'switch',
		'settings'    => 'switch_flags',
		'label'       => esc_html__( 'Enable/Disable Polylang Flags', 'aigen' ),
		'section'     => 'header_section',
		'default'     => 'Off',
		'priority'    => 10,
		'choices'     => [
			'on'  => esc_html__( 'Enable', 'aigen' ),
			'off' => esc_html__( 'Disable', 'aigen' ),
		],
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'switch',
		'settings'    => 'switch_topbar',
		'label'       => esc_html__( 'Enable/Disable Topbar on Home 3', 'aigen' ),
		'section'     => 'header_section',
		'default'     => 'on',
		'priority'    => 10,
		'choices'     => [
			'on'  => esc_html__( 'Enable', 'aigen' ),
			'off' => esc_html__( 'Disable', 'aigen' ),
		],
	)
);


my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'mail_topbar',
		'label'       => esc_attr__( 'Set Up Your E-mail', 'aigen' ),
		'section'     => 'header_section',
	)
);

// top bar menu
my_config_kirki_add_field(
	array(
		'type'        => 'repeater',
		'label'       => esc_html__( 'Top Bar Menu', 'aigen' ),
		'section'     => 'header_section',
		'row_label' => [
			'type'  => 'text',
			'value' => esc_html__( 'Top Bar Nav item', 'aigen' ),
		],
		'button_label' => esc_html__('Add New Item', 'aigen' ),
		'settings'     => 'navs_setting',
        'active_callback' => array(
            array(
                'setting'  => 'nav_setting',
                'operator' => '==',
                'value'    => true,
                ),
        ),
		'fields' => [
			'nav_item' => [
				'type'        => 'select',
				'label'       => __( 'Add Category', 'aigen' ),
				'description' => __( 'Choose Category you want to show', 'aigen' ),
				'priority'    => 10,
				'choices'     => Kirki_Helper::get_terms( 'category' ),
			],
			'nav_icon'  => [
				'type'        => 'select',
				'label'       => esc_html__( 'Add Icon', 'aigen' ),
				'description' => esc_html__( 'Choose FontAwesome icon Class you want to use before link', 'aigen' ),
				'priority'    => 10,
				'choices' => array(
					'fa-plus-square' => 'fa-plus-square',
					'fa-football-ball' => 'fa-football-ball',
					'fa-desktop' => 'fa-desktop',
					'fa-dollar-sign' => 'fa-dollar-sign',
					'fa-user-tie' => 'fa-user-tie',
					'fa-play' => 'fa-play',
					'fa-volume-up' => 'fa-volume-up',
					'fa-flask' => 'fa-flask',
					'fa-microscope' => 'fa-microscope',
					'fa-sim-card' => 'fa-sim-card',
					'fa-image' => 'fa-image',
					'fa-bus' => 'fa-bus',
				),
			],
		]
	)
);


/**footer instagram line**/

my_config_kirki_add_field(
	array(
		'type'        => 'image',
		'settings'    => 'image_setting_url',
		'label'       => esc_html__( 'Background Image', 'aigen' ),
		'description' => esc_html__( 'Page Banner Background Image.', 'aigen' ),
		'section'     => 'page_banner_section',
		'default'     => '',
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'archive_description',
		'label'       => esc_html__( 'Archive Description', 'aigen' ),
		'section'     => 'page_banner_section',
		'default'     => '',
	)
);

/**footer facebook line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'facebook',
		'label'       => esc_attr__( 'Facebook Url', 'aigen' ),
		'section'     => 'social_section',
	)
);

/**footer twitter line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'twitter',
		'label'       => esc_attr__( 'Twitter Url', 'aigen' ),
		'section'     => 'social_section',
	)
);

/**footer linkedin line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'linkedin',
		'label'       => esc_attr__( 'Linkedin Url', 'aigen' ),
		'section'     => 'social_section',
	)
);

/**footer instagram line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'instagram',
		'label'       => esc_attr__( 'Instagram Url', 'aigen' ),
		'section'     => 'social_section',
	)
);

/**footer google line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'google',
		'label'       => esc_attr__( 'Google Url', 'aigen' ),
		'section'     => 'social_section',
	)
);

/**footer youtube line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'youtube',
		'label'       => esc_attr__( 'Youtube Url', 'aigen' ),
		'section'     => 'social_section',
	)
);

/**footer pinterest line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'pinterest',
		'label'       => esc_attr__( 'Pinterest Url', 'aigen' ),
		'section'     => 'social_section',
	)
);

/**footer dribble line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'dribble',
		'label'       => esc_attr__( 'Dribble Url', 'aigen' ),
		'section'     => 'social_section',
	)
);

/**footer github line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'github',
		'label'       => esc_attr__( 'Github Url', 'aigen' ),
		'section'     => 'social_section',
	)
);



my_config_kirki_add_field(
	array(
		'type'        => 'switch',
		'settings'    => 'switch_instagram',
		'label'       => esc_html__( 'Instagram Widget', 'aigen' ),
		'section'     => 'footer_section',
		'default'     => 'Off',
		'priority'    => 10,
		'choices'     => [
			'on'  => esc_html__( 'Enable', 'aigen' ),
			'off' => esc_html__( 'Disable', 'aigen' ),
		],
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'switch',
		'settings'    => 'switch_socials',
		'label'       => esc_html__( 'footer topline with socials', 'aigen' ),
		'section'     => 'footer_section',
		'default'     => 'Off',
		'priority'    => 10,
		'choices'     => [
			'on'  => esc_html__( 'Enable', 'aigen' ),
			'off' => esc_html__( 'Disable', 'aigen' ),
		],
	)
);

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'copyright',
		'label'       => esc_html__( 'Copyright Line Text', 'aigen' ),
		'section'     => 'footer_section',
		'default'     => esc_html__( 'Copyright © aigen.', 'aigen' ),
	)
);



/**footer facebook line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'facebook2',
		'label'       => esc_attr__( 'Facebook Url', 'aigen' ),
		'section'     => 'footer_section',
	)
);

/**footer twitter line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'twitter2',
		'label'       => esc_attr__( 'Twitter Url', 'aigen' ),
		'section'     => 'footer_section',
	)
);

/**footer linkedin line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'linkedin2',
		'label'       => esc_attr__( 'Linkedin Url', 'aigen' ),
		'section'     => 'footer_section',
	)
);

/**footer instagram line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'instagram2',
		'label'       => esc_attr__( 'Instagram Url', 'aigen' ),
		'section'     => 'footer_section',
	)
);

/**footer google line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'google2',
		'label'       => esc_attr__( 'Google Url', 'aigen' ),
		'section'     => 'footer_section',
	)
);

/**footer youtube line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'youtube2',
		'label'       => esc_attr__( 'Youtube Url', 'aigen' ),
		'section'     => 'footer_section',
	)
);

/**footer pinterest line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'pinterest2',
		'label'       => esc_attr__( 'Pinterest Url', 'aigen' ),
		'section'     => 'footer_section',
	)
);

/**footer dribble line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'dribble2',
		'label'       => esc_attr__( 'Dribble Url', 'aigen' ),
		'section'     => 'footer_section',
	)
);

/**footer github line**/

my_config_kirki_add_field(
	array(
		'type'        => 'text',
		'settings'    => 'github2',
		'label'       => esc_attr__( 'Github Url', 'aigen' ),
		'section'     => 'footer_section',
	)
);