<?php
/**
 * aigen Elementor Global Widget About_Block.
 *
 * @package    aigen - Smartbits
 * @subpackage aigen
 * @since      aigen 1.2.3
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Aigen_Elementor_Global_Widgets_About_Block extends Widget_Base {

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_About_Block widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Aigen-Global-Widgets-About-Block';
	}

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_About_Block widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'About Block 1', 'aigen' );
	}

	/**
	 * Retrieve aigen_Elementor_Global_Widget_About_Block widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-monument';
	}

	/**
	 * Retrieve the list of categories the aigen_Elementor_Global_Widget_About_Block widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'aigen-widget-blocks' );
	}
	
	/**
	 * Register aigen_Elementor_Global_Widget_About_Block widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_About_Block_title_manage',
			array(
				'label' => esc_html__( 'About Block', 'aigen' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Section Title:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_subtitle',
			array(
				'label'       => esc_html__( 'Section SubTitle:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom sub title', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_description',
			array(
				'label'       => esc_html__( 'Section Description:', 'aigen' ),
				'type'        => Controls_Manager::WYSIWYG,
				'placeholder' => esc_html__( 'Add your custom block Description', 'aigen' ),
				'label_block' => true,
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'List Text', 'aigen' ),
				'type' => Controls_Manager::TEXTAREA,
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'List Text 1', 'aigen' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'list_title2', [
				'label' => __( 'List Text', 'aigen' ),
				'type' => Controls_Manager::TEXTAREA,
			]
		);

		$this->add_control(
			'list2',
			[
				'label' => __( 'List Text 2', 'aigen' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title2 }}}',
			]
		);

		$this->add_control(
			'widget_image',
			array(
				'label'       => esc_html__( 'Image:', 'aigen' ),
				'type'        => Controls_Manager::MEDIA,
				'placeholder' => esc_html__( 'Add your Image', 'aigen' )
			)
		);
        
		$this->end_controls_section();

	}

	/**
	 * Render Aigen_Elementor_Global_Widgets_About_Block widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();?>
        
        
		<!-- about-section 
			================================================== -->
		<section class="about-section">
            <div class="container">
                <div class="about-box">
                    <div class="row">
                        <?php if($settings['widget_image']['url']) {?>
                            <div class="col-lg-8">
                        <?php } else { ?>
                            <div class="col-lg-12">
                        <?php } ?>
                            <div class="content-text">
                                <div class="title-alternative">
                                    <span class="red-style"><?php echo do_shortcode($settings['widget_subtitle']); ?></span>
                                    <h2><?php echo do_shortcode($settings['widget_title']); ?></h2>
                                </div>
                                <?php echo do_shortcode($settings['widget_description']); ?>
                                <div class="row">
                                    <?php
                                        if($settings['list'] && $settings['list2']) { ?>
                                            <div class="col-lg-6">
                                                <ul class="statistic-list">
                                                    <?php foreach (  $settings['list'] as $item ) { ?>
                                                        <li>
                                                            <?php echo $item['list_title']; ?>
                                                        </li>
                                                    <?php } ?>
                                                </ul>
                                            </div>
                                            <div class="col-lg-6">
                                                <ul class="statistic-list black">
                                                    <?php foreach (  $settings['list2'] as $item ) { ?>
                                                        <li>
                                                            <?php echo $item['list_title2']; ?>
                                                        </li>
                                                    <?php } ?>
                                                </ul>
                                            </div>
                                        <?php } elseif ($settings['list']) {?>
                                            <div class="col-lg-12">
                                                <ul class="statistic-list">
                                                    <?php foreach (  $settings['list'] as $item ) { ?>
                                                        <li>
                                                            <?php echo $item['list_title']; ?>
                                                        </li>
                                                    <?php } ?>
                                                </ul>
                                            </div>
                                        <?php } elseif ($settings['list2']) { ?>
                                            <div class="col-lg-12">
                                                <ul class="statistic-list black">
                                                    <?php foreach (  $settings['list2'] as $item ) { ?>
                                                        <li>
                                                            <?php echo $item['list_title2']; ?>
                                                        </li>
                                                    <?php } ?>
                                                </ul>
                                            </div>
                                        <?php }
                                    ?>
                                </div>
                            </div>
                        </div>

                        <?php if($settings['widget_image']['url']) {?>
                            <div class="col-lg-4">
                                <img src="<?php echo $settings['widget_image']['url']; ?>" alt="">
                            </div>
                        <?php } ?>

                    </div>
                </div>
            </div>
		</section>
        <!-- End about section -->
			
    
    <?php

	}
}
