<?php
/**
 * aigen Elementor Global Widget About_Block2.
 *
 * @package    aigen - Smartbits
 * @subpackage aigen
 * @since      aigen 1.2.3
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Aigen_Elementor_Global_Widgets_About_Block2 extends Widget_Base {

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_About_Block2 widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Aigen-Global-Widgets-About-Block2';
	}

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_About_Block2 widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'About Topics', 'aigen' );
	}

	/**
	 * Retrieve aigen_Elementor_Global_Widget_About_Block2 widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-bookmark';
	}

	/**
	 * Retrieve the list of categories the aigen_Elementor_Global_Widget_About_Block2 widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'aigen-widget-blocks' );
	}
	
	/**
	 * Register aigen_Elementor_Global_Widget_About_Block2 widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_About_Block2_title_manage',
			array(
				'label' => esc_html__( 'About Topics', 'aigen' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Section Title:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_subtitle',
			array(
				'label'       => esc_html__( 'Section SubTitle:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom sub title', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_description',
			array(
				'label'       => esc_html__( 'Section Description:', 'aigen' ),
				'type'        => Controls_Manager::WYSIWYG,
				'placeholder' => esc_html__( 'Add your custom block Description', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_title2',
			array(
				'label'       => esc_html__( 'Special Quote Title:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_description2',
			array(
				'label'       => esc_html__( 'Special Quoate Description:', 'aigen' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Add your custom block Description', 'aigen' ),
				'label_block' => true,
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Services Name', 'aigen' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_icon', [
				'label' => __( 'Services Icon', 'aigen' ),
                'type' => Controls_Manager::ICONS,
                'default' => [
					'value' => 'fas fa-envelope',
					'library' => 'solid',
				],
			]
		);

		$repeater->add_control(
			'list_class', [
				'label' => __( 'Services Icon Color Switch', 'aigen' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __( 'white', 'aigen' ),
				'label_off' => __( 'color', 'aigen' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Services List', 'aigen' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);
        
		$this->end_controls_section();

	}

	/**
	 * Render Aigen_Elementor_Global_Widgets_About_Block2 widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();?>
        
        
		<!-- about-section2 
			================================================== -->
        <section class="about-section2">
            <div class="container">
                <div class="about-box">
                    <div class="row">
                        <?php if($settings['widget_title2']) {?>
                            <div class="col-lg-8">
                        <?php } else { ?>
                            <div class="col-lg-12">
                        <?php } ?>
                            <div class="content-text">
                                <div class="title-alternative">
                                    <span class="red-style"><?php echo do_shortcode($settings['widget_subtitle']); ?></span>
                                    <h2><?php echo do_shortcode($settings['widget_title']); ?></h2>
                                </div>
                                <?php echo do_shortcode($settings['widget_description']); ?>
                            </div>
                        </div>

                        <?php if($settings['widget_title2']) {?>
                            <div class="col-lg-4">
                                <div class="highlight-box">
                                    <h2><?php echo do_shortcode($settings['widget_title2']); ?></h2>
                                    <p><?php echo do_shortcode($settings['widget_description2']); ?></p>
                                </div>
                            </div>
                        <?php } ?>

                    </div>
                </div>
                
                <div class="category-box">
                    <div class="row">
                        
                        <?php foreach (  $settings['list'] as $item ) { ?>
                            <div class="col-lg-3 col-md-6">
                                <div class="category-post <?php if(!$item['list_class']): echo 'diff-style'; endif ?>">
                                    <div class="icon-holder">
                                        <?php Icons_Manager::render_icon( $item['list_icon'], [ 'aria-hidden' => 'true' ] ); ?>
                                    </div>
                                    <span><?php echo $item['list_title']; ?></span>
                                </div>
                            </div>
                            
                        <?php } ?>
                    </div>
                </div>
            </div>
		</section>
        <!-- End about section -->
			
    
    <?php

	}
}
