<?php
/**
 * aigen Elementor Global Widget Contact_Block.
 *
 * @package    aigen - Themewisdom
 * @subpackage aigen
 * @since      aigen 1.0
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Aigen_Elementor_Global_Widgets_Contact_Block extends Widget_Base {

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Contact_Block widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Aigen-Global-Widgets-Contact-Block';
	}

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Contact_Block widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Contact Form Block', 'aigen' );
	}

	/**
	 * Retrieve aigen_Elementor_Global_Widget_Contact_Block widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'far fa-envelope';
	}

	/**
	 * Retrieve the list of categories the aigen_Elementor_Global_Widget_Contact_Block widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'aigen-widget-blocks' );
	}
	
	/**
	 * Register aigen_Elementor_Global_Widget_Contact_Block widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_Contact_Block_title_manage',
			array(
				'label' => esc_html__( 'Contact Form Block', 'aigen' ),
			)
		);

		$this->add_control(
			'widget_contact',
			array(
				'label'       => esc_html__( 'Contact Form 7', 'aigen' ),
				'type'        => Controls_Manager::WYSIWYG,
				'placeholder' => esc_html__( 'Add your Contact Form 7 Shortcode', 'aigen' ),
				'label_block' => true,
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Social Name', 'aigen' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_icon', [
				'label' => __( 'Social Icon', 'aigen' ),
                'type' => Controls_Manager::ICON,
                'include' => [
					'fa fa-facebook',
					'fa fa-flickr',
					'fa fa-google-plus',
					'fa fa-instagram',
					'fa fa-linkedin',
					'fa fa-pinterest',
					'fa fa-reddit',
					'fa fa-twitch',
					'fa fa-twitter',
					'fa fa-vimeo',
					'fa fa-youtube',
				],
			]
		);

		$repeater->add_control(
			'list_url', [
				'label' => __( 'Social Profile URL', 'aigen' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Our Social List', 'aigen' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);
        
		$this->end_controls_section();

	}

	/**
	 * Render Aigen_Elementor_Global_Widgets_Contact_Block widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();?>
        

            <div class="container">
                <div class="contact-form-box">
                    <?php echo do_shortcode($settings['widget_contact']); ?>
                </div>
            </div>
			
    
    <?php

	}
}
