<?php
/**
 * aigen Elementor Global Widget Economy_Block.
 *
 * @package    aigen - Smartbits
 * @subpackage aigen
 * @since      aigen 1.2.3
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Aigen_Elementor_Global_Widgets_Economy_Block extends Widget_Base {

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Economy_Block widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Aigen-Global-Widgets-Economy-Block';
	}

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Economy_Block widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Economy Block 1', 'aigen' );
	}

	/**
	 * Retrieve aigen_Elementor_Global_Widget_Economy_Block widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-money-check-alt';
	}

	/**
	 * Retrieve the list of categories the aigen_Elementor_Global_Widget_Economy_Block widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'aigen-widget-blocks' );
	}
	
	/**
	 * Register aigen_Elementor_Global_Widget_Economy_Block widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_Economy_Block_title_manage',
			array(
				'label' => esc_html__( 'Economy Block 1', 'aigen' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Section Title:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'title_light',
			array(
				'label'       => esc_html__( 'Switch title Color Mode:', 'aigen' ),
				'type'        => Controls_Manager::SWITCHER,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_on' => __( 'Dark', 'aigen' ),
				'label_off' => __( 'Light', 'aigen' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);

		$this->add_control(
			'title_icon',
			array(
				'label'       => esc_html__( 'Switch title Icon (show/hide):', 'aigen' ),
				'type'        => Controls_Manager::SWITCHER,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_on' => __( 'Show', 'aigen' ),
				'label_off' => __( 'Hide', 'aigen' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);

		$this->add_control(
			'image_align',
			[
				'label' => __( 'Large Image Post Align', 'kosovaskills' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'left',
				'options' => [
					'right'  => __( 'Right', 'kosovaskills' ),
					'left' => __( 'Left', 'kosovaskills' ),
				],
			]
		);

        $this->add_control(
			'order',
			array(
				'label'       => esc_html__( 'Sort Posts:', 'aigen' ),
				'type'        => Controls_Manager::SELECT,
				'placeholder' => esc_html__( 'Sort Posts by', 'aigen' ),
				'label_block' => true,
				'default' => 'default',
				'options' => array(
					'default'     => esc_html__( 'Default', 'aigen' ),
					'ASC'     => esc_html__( 'ASC', 'aigen' ),
					'DESC' => esc_html__( 'DESC', 'aigen' ),
				),
			)
		);

		$this->add_control(
			'display_type',
			array(
				'label'   => esc_html__( 'Display the Posts from:', 'aigen' ),
				'type'    => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'latest',
				'options' => array(
					'latest'     => esc_html__( 'Latest Posts', 'aigen' ),
					'categories' => esc_html__( 'Categories', 'aigen' ),
					'tags' => esc_html__( 'Tags', 'aigen' ),
					'popular' => esc_html__( 'Popular (Most Views)', 'aigen' ),
					'comments' => esc_html__( 'Most Commented', 'aigen' ),
					'custom' => esc_html__( 'Custom Posts with ID\'s', 'aigen' ),
				),
			)
		);

		$categories = get_categories();
	    $category_option = array();
        $category_option['all'] = 'all';
        
	    foreach ($categories as $category) {
	        $category_option[$category->name] = $category->slug;
	    }

		$this->add_control(
			'categories_selected',
			array(
				'label'     => esc_html__( 'Select Category:', 'aigen' ),
				'type'      => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'all',
				'options'   => $category_option,
				'condition' => array(
					'display_type' => 'categories',
				),
			)
        );

		$tags = get_tags();
	    $tags_option = array();
        $tags_option['all'] = 'all';
        
	    foreach ($tags as $tag) {
	        $tags_option[$tag->name] = $tag->slug;
	    }

		$this->add_control(
			'tags_selected',
			array(
				'label'     => esc_html__( 'Select Tag:', 'aigen' ),
				'type'      => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'all',
				'options'   => $tags_option,
				'condition' => array(
					'display_type' => 'tags',
				),
			)
        );

		$this->add_control(
			'custom_selected',
			array(
				'label'     => esc_html__( 'Add Posts ID', 'aigen' ),
				'type'      => Controls_Manager::TEXT,
                'description' => esc_html__('Write your post ID\'s saparate them with commas (ex: 15,64,225). Try to make equal with posts per page', 'aigen'),
				'label_block' => true,
				'condition' => array(
					'display_type' => 'custom',
				),
			)
        );
        
		$this->end_controls_section();

	}

	/**
	 * Render Aigen_Elementor_Global_Widgets_Economy_Block widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {

        $widget_title        = $this->get_settings( 'widget_title' );
        $title_light       = $this->get_settings( 'title_light' );
        $title_icon       = $this->get_settings( 'title_icon' );
        $image_align       = $this->get_settings( 'image_align' );
		$display_type        = $this->get_settings( 'display_type' );
		$order        = $this->get_settings( 'order' );
		$categories_selected = $this->get_settings( 'categories_selected' );
		$tags_selected = $this->get_settings( 'tags_selected' );
		$custom_selected = $this->get_settings( 'custom_selected' );

        $args = array(
			'posts_per_page'      => '5',
			'post_type'           => 'post',
			'ignore_sticky_posts' => true,
        );
        
        if ( $order != 'default' ) {
			$args[ 'order' ] = $order;
		}

		// Display from the category selected
		if ( $display_type == 'categories' && $categories_selected !== 'all' ) {
			$args[ 'tax_query' ] = array(
				array(
					'taxonomy' => 'category',
					'field'    => 'slug',
					'terms'    => $categories_selected,
				),
			);
		}

		// Display from the tag selected
		if ( $display_type == 'tags' && $tags_selected !== 'all' ) {
			$args['tag'] = $tags_selected;
		}

		// Display from the most commented
		if ( $display_type == 'comments' ) {
			$args['orderby'] = 'comment_count';
		}

		// Display from the most commented
		if ( $display_type == 'popular' ) {
			$args['meta_key'] = 'post_views_count';
			$args['orderby'] = 'meta_value_num';
		}

		// Display from the most commented
		if ( $display_type == 'custom' ) {
            $postsArray = explode(',', $custom_selected );
            
            $postsCustom = array_values($postsArray);
            

			$args['post__in'] = $postsCustom;
		}

	?>

        <!-- block-section 
			================================================== -->
		<section class="block-section">

            <div class="container">
                <?php
                    if($widget_title) { ?>
                        <div class="title-wrapper <?php if(!$title_light): echo 'white-style'; endif ?>">
                            <h2 <?php if(!$title_icon): echo 'class="no-dottes"'; endif ?> >
                                <?php echo esc_html($widget_title); ?>
                            </h2>
                        </div>
                    <?php }
                ?>
                <div class="economy-box">
                    <?php
                        if($image_align === 'right') { ?>
                            <div class="row reverse-order">
                        <?php } else {?>
                            <div class="row">
                        <?php }

                            $query = new \WP_Query($args);
                            $itemNum = 0;

                            if ( $query->have_posts() ) {
                                while ( $query->have_posts() ) {
                                    $query->the_post(); 
                                    $itemNum = $itemNum + 1;

                                    if($itemNum == 1) { ?>
                                        <div class="col-lg-6">
                                            <div class="image-post2 large-post">
                                                <a href="<?php the_permalink(); ?>"><img src="<?php echo get_the_post_thumbnail_url(); ?>" alt=""></a>
                                                <div class="hover-box">
                                                    <div class="inner-hover">
                                                        <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-lg-6">
                                            <div class="row">
                                    <?php } else { ?>
                                        <div class="col-md-6">
                                            <?php get_template_part( 'template-parts/post-layouts/image-post2' ); ?>
                                        </div>
                                    <?php }
                                }

                                \wp_reset_postdata();
                            } 
                        ?>
                            </div>
                        </div>
                    </div>
                </div>

            </div>
			
		</section>
		<!-- End block section -->
    
    <?php

	}
}
