<?php
/**
 * aigen Elementor Global Widget Large_Carousel.
 *
 * @package    aigen - Smartbits
 * @subpackage aigen
 * @since      aigen 1.2.3
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Aigen_Elementor_Global_Widgets_Large_Carousel extends Widget_Base {

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Large_Carousel widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Aigen-Global-Widgets-Large-Carousel';
	}

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Large_Carousel widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Large Carousel', 'aigen' );
	}

	/**
	 * Retrieve aigen_Elementor_Global_Widget_Large_Carousel widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-grip-lines-vertical';
	}

	/**
	 * Retrieve the list of categories the aigen_Elementor_Global_Widget_Large_Carousel widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'aigen-widget-blocks' );
	}
	
	/**
	 * Register aigen_Elementor_Global_Widget_Large_Carousel widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_large_carousel_title_manage',
			array(
				'label' => esc_html__( 'Large Carousel', 'aigen' ),
			)
		);
		
		$this->add_control(
		    'col_number',
		    [
		        'label' => esc_html__( 'Number of Column', 'aigen' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__('Number of Columns to show in carousel'),
                'default' => 3,
				'label_block' => true,
		    ]
        );
        
		$this->add_control(
		    'widget_number',
		    [
		        'label' => esc_html__( 'Posts Number', 'aigen' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__('Posts number to get from the WP Query (post per page)', 'aigen'),
                'default' => 4,
				'label_block' => true,
		    ]
		);

        $this->add_control(
			'order',
			array(
				'label'       => esc_html__( 'Sort Posts:', 'aigen' ),
				'type'        => Controls_Manager::SELECT,
				'placeholder' => esc_html__( 'Sort Posts by', 'aigen' ),
				'label_block' => true,
				'default' => 'default',
				'options' => array(
					'default'     => esc_html__( 'Default', 'aigen' ),
					'ASC'     => esc_html__( 'ASC', 'aigen' ),
					'DESC' => esc_html__( 'DESC', 'aigen' ),
				),
			)
		);

		$this->add_control(
			'display_type',
			array(
				'label'   => esc_html__( 'Display the Posts from:', 'aigen' ),
				'type'    => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'latest',
				'options' => array(
					'latest'     => esc_html__( 'Latest Posts', 'aigen' ),
					'categories' => esc_html__( 'Categories', 'aigen' ),
					'tags' => esc_html__( 'Tags', 'aigen' ),
					'popular' => esc_html__( 'Popular (Most Views)', 'aigen' ),
					'comments' => esc_html__( 'Most Commented', 'aigen' ),
					'custom' => esc_html__( 'Custom Posts with ID\'s', 'aigen' ),
				),
			)
		);

		$categories = get_categories();
	    $category_option = array();
        $category_option['all'] = 'all';
        
	    foreach ($categories as $category) {
	        $category_option[$category->name] = $category->slug;
	    }

		$this->add_control(
			'categories_selected',
			array(
				'label'     => esc_html__( 'Select Category:', 'aigen' ),
				'type'      => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'all',
				'options'   => $category_option,
				'condition' => array(
					'display_type' => 'categories',
				),
			)
        );

		$tags = get_tags();
	    $tags_option = array();
        $tags_option['all'] = 'all';
        
	    foreach ($tags as $tag) {
	        $tags_option[$tag->name] = $tag->slug;
	    }

		$this->add_control(
			'tags_selected',
			array(
				'label'     => esc_html__( 'Select Tag:', 'aigen' ),
				'type'      => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'all',
				'options'   => $tags_option,
				'condition' => array(
					'display_type' => 'tags',
				),
			)
        );

		$this->add_control(
			'custom_selected',
			array(
				'label'     => esc_html__( 'Add Posts ID', 'aigen' ),
				'type'      => Controls_Manager::TEXT,
                'description' => esc_html__('Write your post ID\'s saparate them with commas (ex: 15,64,225). Try to make equal with posts per page', 'aigen'),
				'label_block' => true,
				'condition' => array(
					'display_type' => 'custom',
				),
			)
        );
        
		$this->end_controls_section();

	}

	/**
	 * Render Aigen_Elementor_Global_Widgets_Large_Carousel widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {

        $posts_number        = $this->get_settings( 'widget_number' );
        $col_number        = $this->get_settings( 'col_number' );
		$display_type        = $this->get_settings( 'display_type' );
		$order        = $this->get_settings( 'order' );
		$categories_selected = $this->get_settings( 'categories_selected' );
		$tags_selected = $this->get_settings( 'tags_selected' );
		$custom_selected = $this->get_settings( 'custom_selected' );

        $args = array(
			'posts_per_page'      => $posts_number,
			'post_type'           => 'post',
			'ignore_sticky_posts' => true,
        );
        
        if ( $order != 'default' ) {
			$args[ 'order' ] = $order;
		}

		// Display from the category selected
		if ( $display_type == 'categories' && $categories_selected !== 'all' ) {
			$args[ 'tax_query' ] = array(
				array(
					'taxonomy' => 'category',
					'field'    => 'slug',
					'terms'    => $categories_selected,
				),
			);
		}

		// Display from the tag selected
		if ( $display_type == 'tags' && $tags_selected !== 'all' ) {
			$args['tag'] = $tags_selected;
		}

		// Display from the most commented
		if ( $display_type == 'comments' ) {
			$args['orderby'] = 'comment_count';
		}

		// Display from the most commented
		if ( $display_type == 'popular' ) {
			$args['meta_key'] = 'post_views_count';
			$args['orderby'] = 'meta_value_num';
		}

		// Display from the most commented
		if ( $display_type == 'custom' ) {
            $postsArray = explode(',', $custom_selected );
            
            $postsCustom = array_values($postsArray);
            

			$args['post__in'] = $postsCustom;
		}

	?>

		<!-- carousel-section 
			================================================== -->
		<section class="carousel-section">
            <div class="carousel-box owl-wrapper">
                
                <div class="owl-carousel" data-num="<?php echo $col_number; ?>">

                    <?php 

                        $query = new \WP_Query($args);

                        if ( $query->have_posts() ) {
                            while ( $query->have_posts() ) {
                                $query->the_post(); ?>
                                <div class="item">
                                    <?php
                                        get_template_part( 'template-parts/post-layouts/image-post' );
                                    ?>
                                </div>
                            <?php }

                            \wp_reset_postdata();
                        } 
                    ?>
                
                </div>

            </div>

		</section>
		<!-- End carousel section -->
			
    
    <?php

	}
}
