<?php
/**
 * aigen Elementor Global Widget Magic_block.
 *
 * @package    aigen - Smartbits
 * @subpackage aigen
 * @since      aigen 1.2.3
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Aigen_Elementor_Global_Widgets_Magic_block extends Widget_Base {

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Magic_block widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Aigen-Global-Widgets-Magic-Block';
	}

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Magic_block widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Magic Block', 'aigen' );
	}

	/**
	 * Retrieve aigen_Elementor_Global_Widget_Magic_block widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-magic';
	}

	/**
	 * Retrieve the list of categories the aigen_Elementor_Global_Widget_Magic_block widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'aigen-widget-blocks' );
	}
	
	/**
	 * Register aigen_Elementor_Global_Widget_Magic_block widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_Magic_block_title_manage',
			array(
				'label' => esc_html__( 'Magic Block', 'aigen' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Section Title:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'title_light',
			array(
				'label'       => esc_html__( 'Switch title Color Mode:', 'aigen' ),
				'type'        => Controls_Manager::SWITCHER,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_on' => __( 'Dark', 'aigen' ),
				'label_off' => __( 'Light', 'aigen' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);

		$this->add_control(
			'title_icon',
			array(
				'label'       => esc_html__( 'Switch title Icon (show/hide):', 'aigen' ),
				'type'        => Controls_Manager::SWITCHER,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_on' => __( 'Show', 'aigen' ),
				'label_off' => __( 'Hide', 'aigen' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);
		
		$this->add_control(
		    'col_number',
		    [
		        'label' => esc_html__( 'Number of Column', 'aigen' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__('Number of Columns to show in carousel'),
                'default' => 3,
				'label_block' => true,
		    ]
        );
        
		$this->add_control(
		    'widget_number',
		    [
		        'label' => esc_html__( 'Posts Number', 'aigen' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__('Posts number to get from the WP Query (post per page)', 'aigen'),
                'default' => 9,
				'label_block' => true,
		    ]
		);

        $this->add_control(
			'order',
			array(
				'label'       => esc_html__( 'Sort Posts:', 'aigen' ),
				'type'        => Controls_Manager::SELECT,
				'placeholder' => esc_html__( 'Sort Posts by', 'aigen' ),
				'label_block' => true,
				'default' => 'default',
				'options' => array(
					'default'     => esc_html__( 'Default', 'aigen' ),
					'ASC'     => esc_html__( 'ASC', 'aigen' ),
					'DESC' => esc_html__( 'DESC', 'aigen' ),
				),
			)
		);

        $this->add_control(
			'sidebar_option',
			array(
				'label'       => esc_html__( 'Sidebar', 'aigen' ),
				'type'        => Controls_Manager::SELECT,
				'placeholder' => esc_html__( 'Sort Posts by', 'aigen' ),
				'label_block' => true,
				'default' => 'right',
				'options' => array(
					'right'     => esc_html__( 'Right', 'aigen' ),
					'left'     => esc_html__( 'Left', 'aigen' ),
					'no' => esc_html__( 'No Sidebar', 'aigen' ),
				),
			)
		);

		$this->add_control(
			'post_style',
			array(
				'label'   => esc_html__( 'Choose Post Style:', 'aigen' ),
				'type'    => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'grid-post',
				'options' => array(
					'grid-post'     => esc_html__( 'Style 1', 'aigen' ),
					'standard-post'     => esc_html__( 'Style 2', 'aigen' ),
					'standard-post2'     => esc_html__( 'Style 3', 'aigen' ),
					'standard-post2-skin'     => esc_html__( 'Style 4', 'aigen' ),
					'article-post'     => esc_html__( 'Style 5', 'aigen' ),
					'card-post'     => esc_html__( 'Style 6', 'aigen' ),
					'card-post-with-padding'     => esc_html__( 'Style 7', 'aigen' ),
					'card-post-skin-color'     => esc_html__( 'Style 8', 'aigen' ),
					'cmd-post'     => esc_html__( 'Style 9', 'aigen' ),
					'image-post'     => esc_html__( 'Style 10', 'aigen' ),
					'image-post2'     => esc_html__( 'Style 11', 'aigen' ),
					'image-post-square'     => esc_html__( 'Style 12', 'aigen' ),
					'image-medium-post'     => esc_html__( 'Style 13', 'aigen' ),
					'line-post'     => esc_html__( 'Style 14', 'aigen' ),
					'overlay-post'     => esc_html__( 'Style 15', 'aigen' ),
					'overlay-post2'     => esc_html__( 'Style 16', 'aigen' ),
				),
			)
		);

        $this->add_control(
			'page_pagination',
			array(
				'label'       => esc_html__( 'Page Pagination', 'aigen' ),
				'type'        => Controls_Manager::SELECT,
				'placeholder' => esc_html__( 'Sort Posts by', 'aigen' ),
				'label_block' => true,
				'default' => 'pagination',
				'options' => array(
					'pagination'     => esc_html__( 'Pagination List', 'aigen' ),
					'load_more'     => esc_html__( 'Ajax Load More', 'aigen' ),
					'infinite_scroll' => esc_html__( 'Infinite Scroll', 'aigen' ),
				),
			)
		);

		$this->add_control(
			'display_type',
			array(
				'label'   => esc_html__( 'Display the Posts from:', 'aigen' ),
				'type'    => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'latest',
				'options' => array(
					'latest'     => esc_html__( 'Latest Posts', 'aigen' ),
					'categories' => esc_html__( 'Categories', 'aigen' ),
					'tags' => esc_html__( 'Tags', 'aigen' ),
					'popular' => esc_html__( 'Popular (Most Views)', 'aigen' ),
					'comments' => esc_html__( 'Most Commented', 'aigen' ),
					'custom' => esc_html__( 'Custom Posts with ID\'s', 'aigen' ),
				),
			)
		);

		$categories = get_categories();
	    $category_option = array();
        $category_option['all'] = 'all';
        
	    foreach ($categories as $category) {
	        $category_option[$category->name] = $category->slug;
	    }

		$this->add_control(
			'categories_selected',
			array(
				'label'     => esc_html__( 'Select Category:', 'aigen' ),
				'type'      => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'all',
				'options'   => $category_option,
				'condition' => array(
					'display_type' => 'categories',
				),
			)
        );

		$tags = get_tags();
	    $tags_option = array();
        $tags_option['all'] = 'all';
        
	    foreach ($tags as $tag) {
	        $tags_option[$tag->name] = $tag->slug;
	    }

		$this->add_control(
			'tags_selected',
			array(
				'label'     => esc_html__( 'Select Tag:', 'aigen' ),
				'type'      => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'all',
				'options'   => $tags_option,
				'condition' => array(
					'display_type' => 'tags',
				),
			)
        );

		$this->add_control(
			'custom_selected',
			array(
				'label'     => esc_html__( 'Add Posts ID', 'aigen' ),
				'type'      => Controls_Manager::TEXT,
                'description' => esc_html__('Write your post ID\'s saparate them with commas (ex: 15,64,225). Try to make equal with posts per page', 'aigen'),
				'label_block' => true,
				'condition' => array(
					'display_type' => 'custom',
				),
			)
        );
        
		$this->end_controls_section();

	}

	/**
	 * Render Aigen_Elementor_Global_Widgets_Magic_block widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {

        $widget_title        = $this->get_settings( 'widget_title' );
        $title_light       = $this->get_settings( 'title_light' );
        $title_icon       = $this->get_settings( 'title_icon' );
        $posts_number        = $this->get_settings( 'widget_number' );
        $col_number        = $this->get_settings( 'col_number' );
        $sidebar_option        = $this->get_settings( 'sidebar_option' );
        $page_pagination        = $this->get_settings( 'page_pagination' );
        $post_style        = $this->get_settings( 'post_style' );
		$display_type        = $this->get_settings( 'display_type' );
		$order        = $this->get_settings( 'order' );
		$categories_selected = $this->get_settings( 'categories_selected' );
		$tags_selected = $this->get_settings( 'tags_selected' );
		$custom_selected = $this->get_settings( 'custom_selected' );
        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

        $args = array(
			'posts_per_page'      => $posts_number,
			'post_type'           => 'post',
            'ignore_sticky_posts' => true,
            'paged'               => $paged
        );
        
        if ( $order != 'default' ) {
			$args[ 'order' ] = $order;
		}

		// Display from the category selected
		if ( $display_type == 'categories' && $categories_selected !== 'all' ) {
			$args[ 'tax_query' ] = array(
				array(
					'taxonomy' => 'category',
					'field'    => 'slug',
					'terms'    => $categories_selected,
				),
			);
		}

		// Display from the tag selected
		if ( $display_type == 'tags' && $tags_selected !== 'all' ) {
			$args['tag'] = $tags_selected;
		}

		// Display from the most commented
		if ( $display_type == 'comments' ) {
			$args['orderby'] = 'comment_count';
		}

		// Display from the most commented
		if ( $display_type == 'popular' ) {
			$args['meta_key'] = 'post_views_count';
			$args['orderby'] = 'meta_value_num';
		}

		// Display from the most commented
		if ( $display_type == 'custom' ) {
            $postsArray = explode(',', $custom_selected );
            
            $postsCustom = array_values($postsArray);
            

			$args['post__in'] = $postsCustom;
		}

	?>

	<!-- recent-section 
		================================================== -->
		<section class="recent-section">

            <div class="container">
                <div class="row <?php if($sidebar_option == 'left') {echo 'reverse-order';} ?>">

                    <?php if( ($sidebar_option == 'left' || $sidebar_option == 'right') && is_active_sidebar('sidebar') ){ ?>
                        <div class="col-lg-8">
                        <?php }else{ ?>
                        <div class="col-lg-12 no-sidebar">
                        <?php } ?>
                        <?php
                            if($widget_title) { ?>
                                <div class="title-wrapper <?php if(!$title_light): echo 'white-style'; endif ?>">
                                    <h2 <?php if(!$title_icon): echo 'class="no-dottes"'; endif ?> >
                                        <?php echo esc_html($widget_title); ?>
                                    </h2>
                                </div>
                            <?php }
                        ?>
                        <div class="recent-box iso-call col<?php echo $col_number; ?>">

                            <?php 
                                $query = new \WP_Query($args);

                                if ( $query->have_posts() ) {
                                    while ( $query->have_posts() ) {
                                        $query->the_post(); ?>
                                        <div class="item">
                                            <?php
                                                get_template_part( 'template-parts/post-layouts/' . $post_style  );
                                            ?>
                                        </div>
                                    <?php }

                                }
                            ?>
                        
                        </div>
                        <?php 

							if($page_pagination == 'pagination') {

								fabric_paging_navigation($query);

							} elseif($page_pagination == 'load_more') {
								// don't display the button if there are not enough posts
								if (  $query->max_num_pages > 1 ) : ?>
									<div class="aigen_loadmore" 
										data-layout="<?php echo $post_style; ?>"
										data-post-num="<?php echo $posts_number; ?>"
										data-order="<?php if ( $order != 'default' ){ echo $order; } ?>"
										data-category="<?php if ( $display_type == 'categories' && $categories_selected !== 'all' ) { echo $categories_selected; } ?>"
										data-tag="<?php if ( $display_type == 'tags' && $tags_selected !== 'all' ) { echo $tags_selected; } ?>"
										data-comment="<?php if ( $display_type == 'comments' ) { echo 'yes'; } ?>"
										data-popular="<?php if ( $display_type == 'popular' ) { echo 'yes'; } ?>"
										data-custom="<?php if ( $display_type == 'custom' ) { echo $custom_selected; } ?>">
										<?php esc_html_e('load more', 'aigen'); ?>
									</div>
									<?php
								endif;
							} elseif($page_pagination == 'infinite_scroll') { ?>
								<div class="aigen_loadmore infinite-box" 
									data-layout="<?php echo $post_style; ?>"
									data-post-num="<?php echo $posts_number; ?>"
									data-order="<?php if ( $order != 'default' ){ echo $order; } ?>"
									data-category="<?php if ( $display_type == 'categories' && $categories_selected !== 'all' ) { echo $categories_selected; } ?>"
									data-tag="<?php if ( $display_type == 'tags' && $tags_selected !== 'all' ) { echo $tags_selected; } ?>"
									data-comment="<?php if ( $display_type == 'comments' ) { echo 'yes'; } ?>"
									data-popular="<?php if ( $display_type == 'popular' ) { echo 'yes'; } ?>"
									data-custom="<?php if ( $display_type == 'custom' ) { echo $custom_selected; } ?>">
								</div>
							<?php }
                             
                            wp_reset_postdata();
                        ?>
                    </div>
                    <?php if(($sidebar_option == 'left' || $sidebar_option == 'right') && is_active_sidebar('sidebar')){ ?>
                    <div class="col-lg-4">
                        
                        <?php get_sidebar(); ?>

                    </div>
                    <?php } ?>
                </div>

            </div>
		</section>
		<!-- End recent section -->
			
    
    <?php
    
	}
}

