<?php
/**
 * aigen Elementor Global Widget Page_Title.
 *
 * @package    aigen - Smartbits
 * @subpackage aigen
 * @since      aigen 1.2.3
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Aigen_Elementor_Global_Widgets_Page_Title extends Widget_Base {

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Page_Title widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Aigen-Global-Widgets-Page-Title';
	}

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Page_Title widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Page Title Block', 'aigen' );
	}

	/**
	 * Retrieve aigen_Elementor_Global_Widget_Page_Title widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-heading';
	}

	/**
	 * Retrieve the list of categories the aigen_Elementor_Global_Widget_Page_Title widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'aigen-widget-blocks' );
	}
	
	/**
	 * Register aigen_Elementor_Global_Widget_Page_Title widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_Page_title_manage',
			array(
				'label' => esc_html__( 'Page Title Block', 'aigen' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Page Title:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom page title', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_description',
			array(
				'label'       => esc_html__( 'Page Description:', 'aigen' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Add your custom page Description', 'aigen' ),
				'label_block' => true,
			)
		);
        
		$this->end_controls_section();

	}

	/**
	 * Render Aigen_Elementor_Global_Widgets_Page_Title widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();?>
        

        <!-- page-banner-section 
            ================================================== -->
        <section class="page-banner-section">
            <div class="container">
                <h2><?php echo do_shortcode($settings['widget_title']); ?></h2>
                <p><?php echo do_shortcode($settings['widget_description']); ?></p>
            </div>
        </section>
        <!-- End page-banner section -->
			
    
    <?php

	}
}
