<?php
/**
 * aigen Elementor Global Widget Slider_Block.
 *
 * @package    aigen - Smartbits
 * @subpackage aigen
 * @since      aigen 1.2.3
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Aigen_Elementor_Global_Widgets_Slider_Block extends Widget_Base {

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Slider_Block widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Aigen-Global-Widgets-Slider-Block';
	}

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Slider_Block widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Slider Block 1', 'aigen' );
	}

	/**
	 * Retrieve aigen_Elementor_Global_Widget_Slider_Block widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fab fa-slideshare';
	}

	/**
	 * Retrieve the list of categories the aigen_Elementor_Global_Widget_Slider_Block widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'aigen-widget-blocks' );
	}
	
	/**
	 * Register aigen_Elementor_Global_Widget_Slider_Block widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_Slider_Block_title_manage',
			array(
				'label' => esc_html__( 'Slider Block 1', 'aigen' ),
			)
		);
        
		$this->add_control(
		    'widget_number',
		    [
		        'label' => esc_html__( 'Posts Number', 'aigen' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__('Posts number to get from the WP Query (post per page)', 'aigen'),
                'default' => 3,
				'label_block' => true,
		    ]
		);

		$this->add_control(
			'display_type',
			array(
				'label'   => esc_html__( 'Display the Posts from:', 'aigen' ),
				'type'    => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'latest',
				'options' => array(
					'latest'     => esc_html__( 'Latest Posts', 'aigen' ),
					'categories' => esc_html__( 'Categories', 'aigen' ),
					'tags' => esc_html__( 'Tags', 'aigen' ),
					'popular' => esc_html__( 'Popular (Most Views)', 'aigen' ),
					'comments' => esc_html__( 'Most Commented', 'aigen' ),
					'custom' => esc_html__( 'Custom Posts with ID\'s', 'aigen' ),
				),
			)
		);

		$categories = get_categories();
	    $category_option = array();
        $category_option['all'] = 'all';
        
	    foreach ($categories as $category) {
	        $category_option[$category->name] = $category->slug;
	    }

		$this->add_control(
			'categories_selected',
			array(
				'label'     => esc_html__( 'Select Category:', 'aigen' ),
				'type'      => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'all',
				'options'   => $category_option,
				'condition' => array(
					'display_type' => 'categories',
				),
			)
        );

		$tags = get_tags();
	    $tags_option = array();
        $tags_option['all'] = 'all';
        
	    foreach ($tags as $tag) {
	        $tags_option[$tag->name] = $tag->slug;
	    }

		$this->add_control(
			'tags_selected',
			array(
				'label'     => esc_html__( 'Select Tag:', 'aigen' ),
				'type'      => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'all',
				'options'   => $tags_option,
				'condition' => array(
					'display_type' => 'tags',
				),
			)
        );

		$this->add_control(
			'custom_selected',
			array(
				'label'     => esc_html__( 'Add Posts ID', 'aigen' ),
				'type'      => Controls_Manager::TEXT,
                'description' => esc_html__('Write your post ID\'s saparate them with commas (ex: 15,64,225). Try to make equal with posts per page', 'aigen'),
				'label_block' => true,
				'condition' => array(
					'display_type' => 'custom',
				),
			)
        );
        
		$this->end_controls_section();

	}

	/**
	 * Render Aigen_Elementor_Global_Widgets_Slider_Block widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {

        $posts_number        = $this->get_settings( 'widget_number' );
		$display_type        = $this->get_settings( 'display_type' );
		$order        = $this->get_settings( 'order' );
		$categories_selected = $this->get_settings( 'categories_selected' );
		$tags_selected = $this->get_settings( 'tags_selected' );
		$custom_selected = $this->get_settings( 'custom_selected' );

        $args = array(
			'posts_per_page'      => $posts_number,
			'post_type'           => 'post',
			'ignore_sticky_posts' => true,
        );
        
        if ( $order != 'default' ) {
			$args[ 'order' ] = $order;
		}

		// Display from the category selected
		if ( $display_type == 'categories' && $categories_selected !== 'all' ) {
			$args[ 'tax_query' ] = array(
				array(
					'taxonomy' => 'category',
					'field'    => 'slug',
					'terms'    => $categories_selected,
				),
			);
		}

		// Display from the tag selected
		if ( $display_type == 'tags' && $tags_selected !== 'all' ) {
			$args['tag'] = $tags_selected;
		}

		// Display from the most commented
		if ( $display_type == 'comments' ) {
			$args['orderby'] = 'comment_count';
		}

		// Display from the most commented
		if ( $display_type == 'popular' ) {
			$args['meta_key'] = 'post_views_count';
			$args['orderby'] = 'meta_value_num';
		}

		// Display from the most commented
		if ( $display_type == 'custom' ) {
            $postsArray = explode(',', $custom_selected );
            
            $postsCustom = array_values($postsArray);
            

			$args['post__in'] = $postsCustom;
		}

	?>

    <!-- slider-section 
			================================================== -->
	    <section class="slider-section fullscreen-slider">
            <div class="flexslider">
                <ul class="slides">
                <?php 

                $query = new \WP_Query($args);

                if ( $query->have_posts() ) {
                    while ( $query->have_posts() ) {
                        $query->the_post(); ?>
                        <li>
                            <div class="full-post">
                                <a href="<?php the_permalink(); ?>"><img src="<?php echo get_the_post_thumbnail_url(); ?>" alt=""></a>
                                <div class="hover-box">
                                    <h2><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
                                </div>
                            </div>
                        </li>
                    <?php }

                    \wp_reset_postdata();
                } 
                ?>

                </ul>
            </div>
            <div class="custom-navigation">
                <a href="#" class="flex-prev">
                    <svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                        viewBox="0 0 238.48 176" style="enable-background:new 0 0 238.48 176;" xml:space="preserve">
                        <g>
                            <path d="M2.34,82.34l80-80c2.29-2.29,5.71-2.96,8.72-1.73C94.05,1.84,96,4.77,96,8v40h142.48v16H88c-4.41,0-8-3.59-8-8V27.31
                                L19.32,88L80,148.69V120c0-4.41,3.59-8,8-8h150.48v16H96v40c0,3.23-1.95,6.16-4.95,7.39C90.07,175.81,89.03,176,88,176
                                c-2.08,0-4.13-0.82-5.66-2.35l-80-80C-0.78,90.53-0.78,85.46,2.34,82.34z"/>
                        </g>
                    </svg>
                    <svg version="1.1" class="hover-svg" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                        viewBox="0 0 238.48 176" style="enable-background:new 0 0 238.48 176;" xml:space="preserve">
                        <g>
                            <path d="M2.34,82.34l80-80c2.29-2.29,5.71-2.96,8.72-1.73C94.05,1.84,96,4.77,96,8v40h142.48v16H88c-4.41,0-8-3.59-8-8V27.31
                                L19.32,88L80,148.69V120c0-4.41,3.59-8,8-8h150.48v16H96v40c0,3.23-1.95,6.16-4.95,7.39C90.07,175.81,89.03,176,88,176
                                c-2.08,0-4.13-0.82-5.66-2.35l-80-80C-0.78,90.53-0.78,85.46,2.34,82.34z"/>
                        </g>
                    </svg>
                </a>
                <a href="#" class="flex-next">
                    <!-- Generator: Adobe Illustrator 23.0.5, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->
                    <svg version="1.1" class="hover-svg" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                        viewBox="0 0 238.48 176" style="enable-background:new 0 0 238.48 176;" xml:space="preserve">
                        <g>
                        <path d="M236.14,93.66l-80,80c-2.29,2.29-5.71,2.96-8.72,1.73c-2.99-1.23-4.95-4.16-4.95-7.39v-40H0l0-16h150.48c4.41,0,8,3.59,8,8
                        v28.69L219.17,88l-60.69-60.69V56c0,4.41-3.59,8-8,8H0l0-16h142.48V8c0-3.23,1.95-6.16,4.95-7.39c0.99-0.42,2.03-0.61,3.05-0.61
                        c2.08,0,4.13,0.82,5.66,2.35l80,80C239.26,85.47,239.26,90.54,236.14,93.66z"/>
                        </g>
                    </svg>
                    <svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
                        viewBox="0 0 238.48 176" style="enable-background:new 0 0 238.48 176;" xml:space="preserve">
                        <g>
                        <path d="M236.14,93.66l-80,80c-2.29,2.29-5.71,2.96-8.72,1.73c-2.99-1.23-4.95-4.16-4.95-7.39v-40H0l0-16h150.48c4.41,0,8,3.59,8,8
                        v28.69L219.17,88l-60.69-60.69V56c0,4.41-3.59,8-8,8H0l0-16h142.48V8c0-3.23,1.95-6.16,4.95-7.39c0.99-0.42,2.03-0.61,3.05-0.61
                        c2.08,0,4.13,0.82,5.66,2.35l80,80C239.26,85.47,239.26,90.54,236.14,93.66z"/>
                        </g>
                    </svg>
                </a>
            </div>

        </section>
    <!-- End slider section -->
    
    <?php

	}
}
