<?php
/**
 * aigen Elementor Global Widget Team_Block.
 *
 * @package    aigen - Smartbits
 * @subpackage aigen
 * @since      aigen 1.2.3
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Aigen_Elementor_Global_Widgets_Team_Block extends Widget_Base {

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Team_Block widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Aigen-Global-Widgets-Team-Block';
	}

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Team_Block widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team Block', 'aigen' );
	}

	/**
	 * Retrieve aigen_Elementor_Global_Widget_Team_Block widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-user-friends';
	}

	/**
	 * Retrieve the list of categories the aigen_Elementor_Global_Widget_Team_Block widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'aigen-widget-blocks' );
	}
	
	/**
	 * Register aigen_Elementor_Global_Widget_Team_Block widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_Team_Block_title_manage',
			array(
				'label' => esc_html__( 'Team Block', 'aigen' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Section Title:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'widget_subtitle',
			array(
				'label'       => esc_html__( 'Section SubTitle:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom sub title', 'aigen' ),
				'label_block' => true,
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'list_title', [
				'label' => __( 'Team Member Name', 'aigen' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_pos', [
				'label' => __( 'Position', 'aigen' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_image', [
				'label' => __( 'Image', 'aigen' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$repeater->add_control(
			'list_fb', [
				'label' => __( 'Facebook Link', 'aigen' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_twitter', [
				'label' => __( 'Twitter Link', 'aigen' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_insta', [
				'label' => __( 'Instagram Link', 'aigen' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$repeater->add_control(
			'list_linkedin', [
				'label' => __( 'Linkedin Link', 'aigen' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Team List', 'aigen' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);

		$repeater = new Repeater();
        
		$this->end_controls_section();

	}

	/**
	 * Render Aigen_Elementor_Global_Widgets_Team_Block widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();?>
        
        <!-- team-section 
			================================================== -->
		<section class="team-section">
            <div class="container">
                <div class="title-alternative">
                    <span><?php echo do_shortcode($settings['widget_subtitle']); ?></span>
                    <h2><?php echo do_shortcode($settings['widget_title']); ?></h2>
                </div>
                <div class="team-box">
                    <div class="row">
                        <?php foreach (  $settings['list'] as $item ) { ?>
                            <div class="col-md-4">
                                <div class="team-post">
                                    <div class="image-holder">
                                        <img src="<?php echo $item['list_image']['url']; ?>" alt="">

                                        <ul class="team-social">
                                            <?php if($item['list_fb']) {?>
                                                <li><a href="<?php echo $item['list_fb']; ?>"><i class="fab fa-facebook-f"></i></a></li>
                                            <?php } ?>
                                            <?php if($item['list_twitter']) {?>
                                                <li><a href="<?php echo $item['list_twitter']; ?>"><i class="fab fa-twitter"></i></a></li>
                                            <?php } ?>
                                            <?php if($item['list_insta']) {?>
                                                <li><a href="<?php echo $item['list_insta']; ?>"><i class="fab fa-instagram"></i></a></li>
                                            <?php } ?>
                                            <?php if($item['list_linkedin']) {?>
                                                <li><a href="<?php echo $item['list_linkedin']; ?>"><i class="fab fa-linkedin-in"></i></a></li>
                                            <?php } ?>

                                        </ul>

                                    </div>
                                    <h3><?php echo $item['list_title']; ?></h3>
                                    <span><?php echo $item['list_pos']; ?></span>
                                </div>
                            </div>
                        <?php } ?>
                    </div>
                </div>
            </div>
		</section>
        <!-- End team section -->
    
    <?php

	}
}
