<?php
/**
 * aigen Elementor Global Widget Trending_Block.
 *
 * @package    aigen - Smartbits
 * @subpackage aigen
 * @since      aigen 1.2.3
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Aigen_Elementor_Global_Widgets_Trending_Block extends Widget_Base {

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Trending_Block widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'Aigen-Global-Widgets-Trending-Block';
	}

	/**
	 * Retrieve Aigen_Elementor_Global_Widgets_Trending_Block widget Title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Trending Block', 'aigen' );
	}

	/**
	 * Retrieve aigen_Elementor_Global_Widget_Trending_Block widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-poll';
	}

	/**
	 * Retrieve the list of categories the aigen_Elementor_Global_Widget_Trending_Block widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'aigen-widget-blocks' );
	}
	
	/**
	 * Register aigen_Elementor_Global_Widget_Trending_Block widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		// Widget title section
		$this->start_controls_section(
			'section_Trending_Block_title_manage',
			array(
				'label' => esc_html__( 'Trending Block', 'aigen' ),
			)
		);

		$this->add_control(
			'widget_title',
			array(
				'label'       => esc_html__( 'Section Title:', 'aigen' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_block' => true,
			)
		);

		$this->add_control(
			'title_light',
			array(
				'label'       => esc_html__( 'Switch title Color Mode:', 'aigen' ),
				'type'        => Controls_Manager::SWITCHER,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_on' => __( 'Dark', 'aigen' ),
				'label_off' => __( 'Light', 'aigen' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);

		$this->add_control(
			'title_icon',
			array(
				'label'       => esc_html__( 'Switch title Icon (show/hide):', 'aigen' ),
				'type'        => Controls_Manager::SWITCHER,
				'placeholder' => esc_html__( 'Add your custom block title', 'aigen' ),
				'label_on' => __( 'Show', 'aigen' ),
				'label_off' => __( 'Hide', 'aigen' ),
				'return_value' => 'yes',
				'default' => 'yes',
			)
		);
        
		$this->add_control(
		    'widget_number',
		    [
		        'label' => esc_html__( 'Posts Number', 'aigen' ),
                'type' => Controls_Manager::NUMBER,
                'description' => esc_html__('Posts number to get from the WP Query (post per page)', 'aigen'),
                'default' => 6,
				'label_block' => true,
		    ]
		);

        $this->add_control(
			'order',
			array(
				'label'       => esc_html__( 'Sort Posts:', 'aigen' ),
				'type'        => Controls_Manager::SELECT,
				'placeholder' => esc_html__( 'Sort Posts by', 'aigen' ),
				'label_block' => true,
				'default' => 'default',
				'options' => array(
					'default'     => esc_html__( 'Default', 'aigen' ),
					'ASC'     => esc_html__( 'ASC', 'aigen' ),
					'DESC' => esc_html__( 'DESC', 'aigen' ),
				),
			)
		);

		$this->add_control(
			'custom_selected',
			array(
				'label'     => esc_html__( 'Add Posts ID', 'aigen' ),
				'type'      => Controls_Manager::TEXT,
                'description' => esc_html__('Write your post ID\'s saparate them with commas (ex: 15,64,225). Try to make equal with posts per page', 'aigen'),
				'label_block' => true,
				'condition' => array(
					'display_type' => 'custom',
				),
			)
        );

        
        $categories = get_categories();
	    $category_option = array();
        
	    foreach ($categories as $category) {
	        $category_option[$category->name] = $category->slug;
        }

        $repeater = new Repeater();
        
		$repeater->add_control(
			'list_title', [
				'label' => __( 'Add Category Name', 'aigen' ),
                'type' => Controls_Manager::TEXT,
			]
		);
        
		$repeater->add_control(
			'cat_list', [
				'label' => __( 'Select Category From Dropdown', 'aigen' ),
                'type' => Controls_Manager::SELECT,
				'default' => $category_option[0],
				'options'   => $category_option,
			]
		);

		$this->add_control(
			'list',
			[
				'label' => __( 'Add Filter Category', 'aigen' ),
                'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ list_title }}}',
			]
		);
        
		$this->end_controls_section();

	}

	/**
	 * Render Aigen_Elementor_Global_Widgets_Trending_Block widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {

        $widget_title        = $this->get_settings( 'widget_title' );
        $title_light       = $this->get_settings( 'title_light' );
        $title_icon       = $this->get_settings( 'title_icon' );
        $posts_number        = $this->get_settings( 'widget_number' );
		$order        = $this->get_settings( 'order' );
		$custom_selected = $this->get_settings( 'custom_selected' );
        $settings = $this->get_settings_for_display();

        $args = array(
			'posts_per_page'      => $posts_number,
			'post_type'           => 'post',
			'ignore_sticky_posts' => true,
        );
        
        if ( $order != 'default' ) {
			$args[ 'order' ] = $order;
        }
        
        if($settings['list']) {
            $catNames = '';
            foreach ( $settings['list'] as $item ) {
                if( $catNames === '' ) {
                    $catNames = $item['cat_list'];
                } else {
                    $catNames = $catNames . ', ' .  $item['cat_list'];
                }
            }

            $args[ 'category_name' ] = $catNames;
        }
        
		// Display from the category selected
		// if ( $display_type == 'categories' && $categories_selected !== 'all' ) {
		// 	
		// }

	?>
        <!-- block-section 
			================================================== -->
		<section class="block-section">
            <div class="container">
                <?php
                    if($widget_title) { ?>
                        <div class="title-wrapper <?php if(!$title_light): echo 'white-style'; endif ?>">
							<h2 <?php if(!$title_icon): echo 'class="no-dottes"'; endif ?> >
                                <?php echo esc_html($widget_title); ?>
                            </h2>
                        </div>
                    <?php }
                ?>
                <div class="block-wrapp">
                    <ul class="filter-block">
                        <?php foreach( $this->get_settings( 'list' ) as $item ) { 
							$category = get_term_by( 'slug', $item['cat_list'], 'category' );
							?>
                            <li>
                                <a href="#" data-cat="<?php echo $category->term_id; ?>"><?php echo $item['list_title']; ?></a>
                            </li>
                        <?php } ?>
					</ul>

					<form action="<?php echo site_url() ?>/wp-admin/admin-ajax.php" method="POST" id="filter">
						<select id="categoryfilter" name="categoryfilter">
							<option value="">Select category...</option>
						</select>
						<input type="hidden" name="action" value="myfilter">
					</form>
					
                    <div class="white-box-wrapper" id="response">

                        <?php 

                            $query = new \WP_Query($args);

                            if ( $query->have_posts() ) {
                                while ( $query->have_posts() ) {
                                    $query->the_post();
                                    get_template_part( 'template-parts/post-layouts/card-post' );
                                }

                                \wp_reset_postdata();
                            } 
                        ?>

					</div>
					<div class="upp-overlay"></div>
                
                </div>

            </div>
		</section>
		<!-- End block section -->
			
    
    <?php

	}
}
